#### 2_create_time_activity_diagram_aggregate_n_differences.R ####

library(tidyverse)
library(sp)
library(maptools)
library(templates)
library(raster)
library(rgdal)
library(haven)
library(data.table)
library(car)
library(RColorBrewer)
library(varhandle)
library(grDevices)
library(dplyr)
library(graphics)
library(plotrix)

# Set up work directory
setwd("C:\\Timeline_diagrams")
getwd()

# set Y at the bottom and the top
Yb <- 6*60*2
Yt <- 24*60*2

myDep <- 1
actAgglwd = 0.9
myDiffFactor = 9

# read df.t_num
df.t_num <- readRDS("df.t_num.rds")

# set vertical positions
Xl = -300
Xr = 280

Xleft <- -520 - 60
Xright <- 3000

Xright2 <- Xr +240 +40
Xleft2 <- Xr +240 + 40 + 100
df.t_num$Xl <- Xl

interval <- (Xright -Xleft2 - 100)/4
interval1 <- interval/2
interval_4 <- Xleft2 + 50 + interval1
interval_2 <- interval_4 + interval
interval_1 <- interval_4 + interval*2
interval_5 <- interval_4 + interval*3

# set color
# dark green
col4 <- "#1b7837"
col4a <- "#1b7837CC"

# light green
col2 <- "#5aae61"
col2a <- "#a6dba0CC"

# orange
col1 <- "#fdbf6f"
col1a <- "#fdbf6fBF"

# purple
col5 <- "#c2a5cf"

# grey and black
col_grey <- "#525252"
col_lightgrey <- "#d9d9d9"
col_black <- "#252525"


# set file name ####
myfile<-paste("Obese_Boys_IMDQ", myDep, "_active_Boy_aggregates_n_mean_pct_diff_test2.png",sep='')

png(myfile, width=20, height=15, units = "cm", res = 2400, pointsize = 10)

# add an empty plot ####
plot(1, type="n", xlab="", ylab="", xlim=c((Xleft - 100), (Xright+20)),
     ylim=c((Yb-260), (Yt + 180)), axes=FALSE, ann=FALSE)

# draw rectangle
rect(Xleft2, 6*120, Xright, 24*120, density = NULL,
     col = "white", border = NULL)

rect(Xleft, 6*120, Xright2, 24*120, density = NULL,
     col = "white", border = NULL)

## plot hour referencing lines

for (i in seq(6, 24, by = 3)) {
  # hour referencing lines
  segments((Xleft), i*120, Xright, i*120, col = col_grey, lty = , lwd = 0.4)
  #label hour
  lab <- paste(c(i, ":00"), collapse = "")
  text((Xleft), i*120, lab, cex = .9, pos = 2)
}


# Load rds files (they were created with R Code 1:
# 1_set_up_n_create_time_activity_diagram_individual_n_aggregate.R)

# aggregates
sumboynormal5X <- readRDS("IMD1_obese_active_Boy_sumnormal5X.rds")
sumboyobese5X <- readRDS("IMD1_obese_active_Boy_sumobese5X.rds")

sumboynormal4X <- readRDS("IMD1_obese_active_Boy_sumnormal4X.rds")
sumboyobese4X <- readRDS("IMD1_obese_active_Boy_sumobese4X.rds")

sumboynormal2X <- readRDS("IMD1_obese_active_Boy_sumnormal2X.rds")
sumboyobese2X <- readRDS("IMD1_obese_active_Boy_sumobese2X.rds")

sumboynormal1X <- readRDS("IMD1_obese_active_Boy_sumnormal1X.rds")
sumboyobese1X <- readRDS("IMD1_obese_active_Boy_sumobese1X.rds")

# mean differences
sumboynormal5X2 <- readRDS("IMD1_obese_active_Boy_sumnormal5X2.rds")
sumboyobese5X2 <- readRDS("IMD1_obese_active_Boy_sumobese5X2.rds")

sumboynormal4X2 <- readRDS("IMD1_obese_active_Boy_sumnormal4X2.rds")
sumboyobese4X2 <- readRDS("IMD1_obese_active_Boy_sumobese4X2.rds")

sumboynormal2X2 <- readRDS("IMD1_obese_active_Boy_sumnormal2X2.rds")
sumboyobese2X2 <- readRDS("IMD1_obese_active_Boy_sumobese2X2.rds")

sumboynormal1X2 <- readRDS("IMD1_obese_active_Boy_sumnormal1X2.rds")
sumboyobese1X2 <- readRDS("IMD1_obese_active_Boy_sumobese1X2.rds")

# plot aggregates normal 5 ####
sumboynormal5X$Xl <- Xl
coordinates(sumboynormal5X)= ~Xl + time_num

x <- lapply(split(sumboynormal5X, sumboynormal5X$min2), function(x)
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboynormal5X <- SpatialLines(x)

sumboynormal5X2 <- as.data.frame(sumboynormal5X2)

# add data to SpatialLinesDataFrame
rownames(sumboynormal5X2) <- sumboynormal5X2$min2

spdflines_sumboynormal5X <- 
  SpatialLinesDataFrame(lines_sumboynormal5X,
                        data.frame(data =sumboynormal5X2), match.ID=TRUE)

plot(spdflines_sumboynormal5X, 
     lwd = (data.frame(sumboynormal5X2)$mean_act_pct*actAgglwd),
     col = col5, lend = 1, add = TRUE)

# plot aggregates normal 1 ####
sumboynormal1X$Xl <- Xl
coordinates(sumboynormal1X)= ~Xl + time_num

x <- lapply(split(sumboynormal1X, sumboynormal1X$min2), function(x)
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboynormal1X <- SpatialLines(x)

sumboynormal1X2 <- as.data.frame(sumboynormal1X2)

# add data to SpatialLinesDataFrame
rownames(sumboynormal1X2) <- sumboynormal1X2$min2

spdflines_sumboynormal1X <- 
  SpatialLinesDataFrame(lines_sumboynormal1X, 
                        data.frame(data =sumboynormal1X2), match.ID=TRUE)

plot(spdflines_sumboynormal1X,
     lwd = (data.frame(sumboynormal1X2)$mean_act_pct*actAgglwd),
     col = (data.frame(sumboynormal1X2)$col), lend = 1, add = TRUE)

# plot aggregates normal 2 ####
sumboynormal2X$Xl <- Xl
coordinates(sumboynormal2X)= ~Xl + time_num

x <- lapply(split(sumboynormal2X, sumboynormal2X$min2), function(x)
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboynormal2X <- SpatialLines(x)

sumboynormal2X2 <- as.data.frame(sumboynormal2X2)

# add data to SpatialLinesDataFrame
rownames(sumboynormal2X2) <- sumboynormal2X2$min2

spdflines_sumboynormal2X <- 
  SpatialLinesDataFrame(lines_sumboynormal2X, 
                        data.frame(data =sumboynormal2X2), match.ID=TRUE)

plot(spdflines_sumboynormal2X, 
     lwd = (data.frame(sumboynormal2X2)$mean_act_pct*actAgglwd), 
     col = (data.frame(sumboynormal2X2)$col), lend = 1, add = TRUE)

# plot aggregates normal 4 ####
sumboynormal4X$Xl <- Xl
coordinates(sumboynormal4X)= ~Xl + time_num

x <- lapply(split(sumboynormal4X, sumboynormal4X$min2), function(x)
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboynormal4X <- SpatialLines(x)

sumboynormal4X2 <- as.data.frame(sumboynormal4X2)

# add data to SpatialLinesDataFrame
rownames(sumboynormal4X2) <- sumboynormal4X2$min2

spdflines_sumboynormal4X <-
  SpatialLinesDataFrame(lines_sumboynormal4X, 
                        data.frame(data =sumboynormal4X2), match.ID=TRUE)

plot(spdflines_sumboynormal4X, 
     lwd = (data.frame(sumboynormal4X2)$mean_act_pct*actAgglwd),
     col = col4a, lend = 1, add = TRUE)

# plot aggregates obese 5 ####
sumboyobese5X$Xr <- Xr
coordinates(sumboyobese5X)= ~Xr + time_num

x <- lapply(split(sumboyobese5X, sumboyobese5X$min2), function(x)
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboyobese5X <- SpatialLines(x)

sumboyobese5X2 <- as.data.frame(sumboyobese5X2)

# add data to SpatialLinesDataFrame
rownames(sumboyobese5X2) <- sumboyobese5X2$min2

spdflines_sumboyobese5X <- 
  SpatialLinesDataFrame(lines_sumboyobese5X,
                        data.frame(data =sumboyobese5X2), match.ID=TRUE)

plot(spdflines_sumboyobese5X, 
     lwd = (data.frame(sumboyobese5X2)$mean_act_pct*actAgglwd),
     col= col5, lend = 1, add = TRUE)

# plot aggregates obese 1 ####
sumboyobese1X$Xr <- Xr
coordinates(sumboyobese1X)= ~Xr + time_num

x <- lapply(split(sumboyobese1X, sumboyobese1X$min2), function(x)
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboyobese1X <- SpatialLines(x)

sumboyobese1X2 <- as.data.frame(sumboyobese1X2)

# add data to SpatialLinesDataFrame
rownames(sumboyobese1X2) <- sumboyobese1X2$min2

spdflines_sumboyobese1X <- 
  SpatialLinesDataFrame(lines_sumboyobese1X, 
                        data.frame(data =sumboyobese1X2), match.ID=TRUE)

plot(spdflines_sumboyobese1X,
     lwd = (data.frame(sumboyobese1X2)$mean_act_pct*actAgglwd), 
     col = (data.frame(sumboyobese1X2)$col), lend = 1, add = TRUE)

# plot aggregates obese 2 ####
sumboyobese2X$Xr <- Xr
coordinates(sumboyobese2X)= ~Xr + time_num

x <- lapply(split(sumboyobese2X, sumboyobese2X$min2), function(x) 
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboyobese2X <- SpatialLines(x)

sumboyobese2X2 <- as.data.frame(sumboyobese2X2)

# add data to SpatialLinesDataFrame
rownames(sumboyobese2X2) <- sumboyobese2X2$min2

spdflines_sumboyobese2X <- 
  SpatialLinesDataFrame(lines_sumboyobese2X,
                        data.frame(data =sumboyobese2X2), match.ID=TRUE)

plot(spdflines_sumboyobese2X, 
     lwd = (data.frame(sumboyobese2X2)$mean_act_pct*actAgglwd),
     col = (data.frame(sumboyobese2X2)$col), lend = 1, add = TRUE)

# plot aggregates obese 4 ####
sumboyobese4X$Xr <- Xr
coordinates(sumboyobese4X)= ~Xr + time_num

x <- lapply(split(sumboyobese4X, sumboyobese4X$min2), function(x) 
  Lines(list(Line(coordinates(x))), x$min2[1L]))

lines_sumboyobese4X <- SpatialLines(x)

sumboyobese4X2 <- as.data.frame(sumboyobese4X2)

# add data to SpatialLinesDataFrame
rownames(sumboyobese4X2) <- sumboyobese4X2$min2

spdflines_sumboyobese4X <- 
  SpatialLinesDataFrame(lines_sumboyobese4X,
                        data.frame(data =sumboyobese4X2), match.ID=TRUE)

plot(spdflines_sumboyobese4X, 
     lwd = (data.frame(sumboyobese4X2)$mean_act_pct*actAgglwd),
     col = col4a, lend = 1, add = TRUE)


# mean diff for act 4####

# rename variables
colnames(sumboynormal4X2)[1] <- "mean_act_pct_normal"
colnames(sumboyobese4X2)[1] <- "mean_act_pct_obese"

sumboy_merge_4X2 <- sumboynormal4X2 %>%
  full_join(sumboyobese4X2, by ="min2") %>%
  distinct()

# replace NA with 0 and create a diff variable
sumboy_merge_4X2 <- sumboy_merge_4X2 %>%
  mutate(mean_act_pct_normal = if_else(is.na(mean_act_pct_normal), 0, mean_act_pct_normal)) %>%
  mutate(mean_act_pct_obese = if_else(is.na(mean_act_pct_obese), 0, mean_act_pct_obese)) %>%
  mutate(mean_act_pct_diff = mean_act_pct_normal - mean_act_pct_obese) %>%
  mutate(X4 = interval_4 + mean_act_pct_diff*myDiffFactor) %>%
  mutate(path = 1)


sumboy_merge_4X2_L2 <- sumboy_merge_4X2 %>%
  mutate(min2_2 = min2 -20)


# plot mean diff segments ####
v <- list()
v$x <- sumboy_merge_4X2$X4
v$y <- sumboy_merge_4X2$min2
v$y2 <- sumboy_merge_4X2$min2-20
v$xy <- c(v$x, v$y)  

begin.coord <- data.frame(lon=v$x, lat=v$y)
end.coord <- data.frame(lon=v$x, lat=v$y2)

l <- vector("list", nrow(begin.coord))
library(sp)
for (i in seq_along(l)) {
  l[[i]] <- Lines(list(Line(rbind(begin.coord[i, ], end.coord[i,]))), as.character(i))
}

sl <- SpatialLines(l)

segments((interval_4), Yb, (interval_4), Yt, col = col_lightgrey, lty = , lwd = 1.0)
plot(sl, col = col4, lend = 1, lwd = 2, add = TRUE)

# mean diff for act 2####

# rename variables
colnames(sumboynormal2X2)[1] <- "mean_act_pct_normal"
colnames(sumboyobese2X2)[1] <- "mean_act_pct_obese"

sumboy_merge_2X2 <- sumboynormal2X2 %>%
  full_join(sumboyobese2X2, by ="min2") %>%
  distinct()

# replace NA with 0
sumboy_merge_2X2 <- sumboy_merge_2X2 %>%
  mutate(mean_act_pct_normal = if_else(is.na(mean_act_pct_normal), 0, mean_act_pct_normal)) %>%
  mutate(mean_act_pct_obese = if_else(is.na(mean_act_pct_obese), 0, mean_act_pct_obese)) %>%
  mutate(mean_act_pct_diff = mean_act_pct_normal - mean_act_pct_obese) %>%
  mutate(X2 = interval_2 + mean_act_pct_diff*myDiffFactor) %>%
  mutate(path = 1)

sumboy_merge_2X2_L2 <- sumboy_merge_2X2 %>%
  mutate(min2_2 = min2 -20)

# plot mean diff segments ####
v <- list()
v$x <- sumboy_merge_2X2$X2
v$y <- sumboy_merge_2X2$min2
v$y2 <- sumboy_merge_2X2$min2-20
v$xy <- c(v$x, v$y)  

begin.coord <- data.frame(lon=v$x, lat=v$y)
end.coord <- data.frame(lon=v$x, lat=v$y2)

l <- vector("list", nrow(begin.coord))
library(sp)
for (i in seq_along(l)) {
  l[[i]] <- Lines(list(Line(rbind(begin.coord[i, ], end.coord[i,]))), as.character(i))
}

sl <- SpatialLines(l)

segments((interval_2), Yb, (interval_2), Yt, col = col_lightgrey, lty = , lwd = 1.0)
plot(sl, col = col2, lend = 1, lwd = 2, add = TRUE)


# mean diff for act 1####

# rename variables
colnames(sumboynormal1X2)[1] <- "mean_act_pct_normal"
colnames(sumboyobese1X2)[1] <- "mean_act_pct_obese"

sumboy_merge_1X2 <- sumboynormal1X2 %>%
  full_join(sumboyobese1X2, by ="min2") %>%
  distinct()

# replace NA with 0
sumboy_merge_1X2 <- sumboy_merge_1X2 %>%
  mutate(mean_act_pct_normal = if_else(is.na(mean_act_pct_normal), 0, mean_act_pct_normal)) %>%
  mutate(mean_act_pct_obese = if_else(is.na(mean_act_pct_obese), 0, mean_act_pct_obese)) %>%
  mutate(mean_act_pct_diff = mean_act_pct_normal - mean_act_pct_obese) %>%
  mutate(X1 = interval_1 + mean_act_pct_diff*myDiffFactor) %>%
  mutate(path = 1)

sumboy_merge_1X2_L2 <- sumboy_merge_1X2 %>%
  mutate(min2_2 = min2 -20)


# plot mean diff segments ####
v <- list()
v$x <- sumboy_merge_1X2$X1
v$y <- sumboy_merge_1X2$min2
v$y2 <- sumboy_merge_1X2$min2-20
v$xy <- c(v$x, v$y)  

begin.coord <- data.frame(lon=v$x, lat=v$y)
end.coord <- data.frame(lon=v$x, lat=v$y2)

l <- vector("list", nrow(begin.coord))
library(sp)
for (i in seq_along(l)) {
  l[[i]] <- Lines(list(Line(rbind(begin.coord[i, ], end.coord[i,]))), as.character(i))
}

sl <- SpatialLines(l)

segments((interval_1), Yb, (interval_1), Yt, col = col_lightgrey, lty = , lwd = 1.0)
plot(sl, col = col1, lend = 1, lwd = 2, add = TRUE)

# mean diff for act 5####

# rename variables
colnames(sumboynormal5X2)[1] <- "mean_act_pct_normal"
colnames(sumboyobese5X2)[1] <- "mean_act_pct_obese"

sumboy_merge_5X2 <- sumboynormal5X2 %>%
  full_join(sumboyobese5X2, by="min2") %>%
  distinct()

# replace NA with 0
sumboy_merge_5X2 <- sumboy_merge_5X2 %>%
  mutate(mean_act_pct_normal = if_else(is.na(mean_act_pct_normal), 0, mean_act_pct_normal)) %>%
  mutate(mean_act_pct_obese = if_else(is.na(mean_act_pct_obese), 0, mean_act_pct_obese)) %>%
  mutate(mean_act_pct_diff = mean_act_pct_normal - mean_act_pct_obese) %>%
  mutate(X5 = interval_5 + mean_act_pct_diff*myDiffFactor) %>%
  mutate(path = 1)


sumboy_merge_5X2_L2 <- sumboy_merge_5X2 %>%
  mutate(min2_2 = min2 -20)


# plot mean diff segments ####
v <- list()
v$x <- sumboy_merge_5X2$X5
v$y <- sumboy_merge_5X2$min2
v$y2 <- sumboy_merge_5X2$min2-20
v$xy <- c(v$x, v$y)  

begin.coord <- data.frame(lon=v$x, lat=v$y)
end.coord <- data.frame(lon=v$x, lat=v$y2)

l <- vector("list", nrow(begin.coord))
library(sp)
for (i in seq_along(l)) {
  l[[i]] <- Lines(list(Line(rbind(begin.coord[i, ], end.coord[i,]))), as.character(i))
}

sl <- SpatialLines(l)

segments((interval_5), Yb, (interval_5), Yt, col = col_lightgrey, lty = , lwd = 1.0)
plot(sl, col = col5, lend = 1, lwd = 2, add = TRUE)

segments((Xl), (Yb-61.5), (Xl), (Yb-63.5), col = "black", lty = , lend = 1, lwd = (100*actAgglwd))
segments((Xl - 150-120), (Yb - 52.5), (Xl - 150-120), (Yb - 72.5), col = "black", lty = , lwd = 1)
segments((Xl + 150 +120), (Yb - 52.5), (Xl + 150 +120), (Yb - 72.5), col = "black", lty = , lwd = 1)

boxed.labels((Xl), (Yb-62.5),"100%",bg="white",border=NA, cex = .9) 

text((Xl+280), (Yb-70), lab="Mean % of activities", cex = .9, pos = 1, font=1)

segments((Xr), (Yb-61.5), (Xr), (Yb-63.5), col = "black", lty = , lend = 1, lwd = (100*actAgglwd))
segments((Xr - 150-120), (Yb - 52.5), (Xr - 150-120), (Yb - 72.5), col = "black", lty = , lwd = 1)
segments((Xr + 150 +120), (Yb - 52.5), (Xr + 150 +120), (Yb - 72.5), col = "black", lty = , lwd = 1)

boxed.labels((Xr), (Yb-62.5),"100%",bg="white",border=NA, cex = .9)

#### legend ####

# # horizontal box lines
segments((Xleft), Yt, (Xright2), Yt, col = "black", lty = , lwd = 1)
segments((Xleft), Yb, (Xright2), Yb, col = "black", lty = , lwd = 1)
segments((Xright), Yt, (Xleft2), Yt, col = "black", lty = , lwd = 1)
segments((Xright), Yb, (Xleft2), Yb, col = "black", lty = , lwd = 1)
# 
# # vertical box lines
segments((Xleft), Yb, (Xleft), Yt, col = "black", lty = , lwd = 1)
segments((Xr +240+40), Yb, (Xr +240+40), Yt, col = "black", lty = , lwd = 1)
segments((Xright), Yb, (Xright), Yt, col = "black", lty = , lwd = 1)
segments((Xr +240 + 40+100), Yb, (Xr +240 +40+100), Yt, col = "black", lty = , lwd = 1)
# 
# # legends and labels for act %
text((Xleft-30), (Yt+60), lab="Uw/Normal", cex = 1.0, pos = 4, font=1)
text((0), (Yt+60), lab="Ow/Obese", cex = 1.0, pos = 4, font=1)
text((Xleft2 - 20), (Yt+60), 
     lab="Mean percentage difference between the two groups by activity",
     cex = 1.0, pos = 4, font=1)

text((interval_4), (Yb-40), lab='0', cex = .9, pos = 1, font=1)
text((interval_4 + 10*myDiffFactor), (Yb-40), lab='10', cex = .9, pos = 1, font=1)
text((interval_4 - 10*myDiffFactor), (Yb-40), lab='-10', cex = .9, pos = 1, font=1)
segments((interval_4), (Yb), (interval_4), (Yb-20), col = col_grey, lty = , lwd = 1.0)
segments((interval_4+ 10*myDiffFactor), (Yb), (interval_4+ 10*myDiffFactor), (Yb-20), 
         col = col_grey, lty = , lwd = 1.0)
segments((interval_4 - 10*myDiffFactor), (Yb), (interval_4 - 10*myDiffFactor), (Yb-20),
         col = col_grey, lty = , lwd = 1.0)

text((interval_2), (Yb-40), lab='0', cex = .9, pos = 1, font=1)
text((interval_2 + 10*myDiffFactor), (Yb-40), lab='10', cex = .9, pos = 1, font=1)
text((interval_2 - 10*myDiffFactor), (Yb-40), lab='-10', cex = .9, pos = 1, font=1)
segments((interval_2), (Yb), (interval_2), (Yb-20), col = col_grey, lty = , lwd = 1.0)
segments((interval_2 + 10*myDiffFactor), (Yb), (interval_2 + 10*myDiffFactor), (Yb-20), 
         col = col_grey, lty = , lwd = 1.0)
segments((interval_2 - 10*myDiffFactor), (Yb), (interval_2 - 10*myDiffFactor), (Yb-20),
         col = col_grey, lty = , lwd = 1.0)


text((interval_1), (Yb-40), lab='0', cex = .9, pos = 1, font=1)
text((interval_1 + 10*myDiffFactor), (Yb-40), lab='10', cex = .9, pos = 1, font=1)
text((interval_1 - 10*myDiffFactor), (Yb-40), lab='-10', cex = .9, pos = 1, font=1)
segments((interval_1), (Yb), (interval_1), (Yb-20), col = col_grey, lty = , lwd = 1.0)
segments((interval_1 + 10*myDiffFactor), (Yb), (interval_1 + 10*myDiffFactor), (Yb-20),
         col = col_grey, lty = , lwd = 1.0)
segments((interval_1 - 10*myDiffFactor), (Yb), (interval_1 - 10*myDiffFactor), (Yb-20), 
         col = col_grey, lty = , lwd = 1.0)


text((interval_5), (Yb-40), lab='0', cex = .9, pos = 1, font=1)
text((interval_5 + 10*myDiffFactor), (Yb-40), lab='10', cex = .9, pos = 1, font=1)
text((interval_5 - 10*myDiffFactor), (Yb-40), lab='-10', cex = .9, pos = 1, font=1)
segments((interval_5), (Yb), (interval_5), (Yb-20), col = col_grey, lty = , lwd = 1.0)
segments((interval_5 + 10*myDiffFactor), (Yb), (interval_5 + 10*myDiffFactor), (Yb-20),
         col = col_grey, lty = , lwd = 1.0)
segments((interval_5 - 10*myDiffFactor), (Yb), (interval_5 - 10*myDiffFactor), (Yb-20),
         col = col_grey, lty = , lwd = 1.0)

text((interval_5 + 10*myDiffFactor + 160), (Yb-40), lab='(%)', cex = .9, pos = 1, font=1)

# point legend
segdist <- ((Xright - Xleft) + 200)/5 + 180

# dark green
points((Xleft+20), (Yb-270), bg = col4a, cex = 2, cex.lab = 1.0, pch = 22, col = NA)
points((Xleft+ 20+80), (Yb-270), bg = col4, cex = 2, cex.lab = 1.0,pch = 22, col = NA)
text((Xleft+20 +100), (Yb-270), lab="MVPA", cex = 1.0, pos = 4, font=1)

# light green
points((Xleft + segdist), (Yb-270), bg = col2a, cex = 2, cex.lab = 1.0, pch = 22, col = NA)
points((Xleft + segdist + 80), (Yb-270), bg = col2, cex = 2, cex.lab = 1.0, pch = 22, col = NA)
text((Xleft + segdist + 100), (Yb-270), lab="LPA", cex = 1.0, pos = 4, font=1)

# orange
points((Xleft + segdist*2), (Yb-270), bg = col1a, cex = 2, cex.lab = 1.0, pch = 22, col = NA)
points((Xleft + segdist*2 + 80), (Yb-270), bg = col1, cex = 2, cex.lab = 1.0, pch = 22, col = NA)
text((Xleft + segdist*2 + 100), (Yb-270), lab="SB", cex = 1.0, pos = 4, font=1)

# purple
points((Xleft + segdist*3), (Yb-270), bg = col5, cex = 2, cex.lab = 1.0, pch = 22, col = NA)
points((Xleft + segdist*3 + 80), (Yb-270), bg = col5, cex = 2, cex.lab = 1.0, pch = 22, col = NA)
text((Xleft + segdist*3 + 100), (Yb-270), lab="Sleep", cex = 1.0, pos = 4, font=1)


dev.off()
